API Reference
=============

A start on a more complete, method-by-method reference:

.. autoclass:: quoter.Quoter
   :members:
   :undoc-members:
   :special-members: __init__,__call__
   :inherited-members:

.. autoclass:: quoter.LambdaQuoter
   :members:
   :undoc-members:
   :special-members: __init__,__call__
   :inherited-members:

.. autoclass:: quoter.XMLQuoter
   :members:
   :undoc-members:
   :special-members: __init__,__call__
   :inherited-members:

.. autoclass:: quoter.HTMLQuoter
   :members:
   :undoc-members:
   :special-members: __init__,__call__
   :inherited-members:

.. autoclass:: quoter.Markdown
   :members:
   :undoc-members:
   :special-members: __init__,__call__
   :inherited-members:

.. autodata:: quoter.quote
   :annotation: Default ``StyleSet`` for ``Quoter`` objects

.. autodata:: quoter.lambdaq
   :annotation: Default ``StyleSet`` for ``LambdaQuoter`` objects

.. autodata:: quoter.xml
   :annotation: Default ``StyleSet`` for ``XMLQuoter`` objects

.. autodata:: quoter.html
   :annotation: Default ``StyleSet`` for ``HTMLQuoter`` objects

.. autodata:: quoter.md
   :annotation: Default ``StyleSet`` for ``Markdown`` objects